@@ -41,8 +41,6 @@
 
 #define KCONFIGWIDGETS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KCONFIGWIDGETS_NO_DEPRECATED) && !defined(KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KCONFIGWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONFIGWIDGETS_NO_DEPRECATED
-#  define KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
 #endif
 #ifdef KCONFIGWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56b00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KCONFIGWIDGETS_DEPRECATED
-#  define KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KCONFIGWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
@@ -211,6 +209,18 @@
 #else
 #  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_103(text)
 #endif
+
+#if KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x56a00
+#  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_106(text) KCONFIGWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_106(text)
+#endif
+
+#if KCONFIGWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x56b00
+#  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_107(text) KCONFIGWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCONFIGWIDGETS_DEPRECATED_VERSION_5_107(text)
+#endif
 #define KCONFIGWIDGETS_DEPRECATED_VERSION_4(minor, text)      KCONFIGWIDGETS_DEPRECATED_VERSION_4_##minor(text)
 #define KCONFIGWIDGETS_DEPRECATED_VERSION_5(minor, text)      KCONFIGWIDGETS_DEPRECATED_VERSION_5_##minor(text)
 #define KCONFIGWIDGETS_DEPRECATED_VERSION(major, minor, text) KCONFIGWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
